# -------------------------------------------------------------------------------
# Generated by PixieDust code generator
# 
# Licensed under the Apache License, Version 2.0 (the 'License');
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
# http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# Inherited from maven-artifact https://github.com/hamnis/maven-artifact
# -------------------------------------------------------------------------------

from .display import WordCloudDisplayHandler
from pixiedust.display.display import *

@PixiedustDisplay()
class WordCloudDisplayHandlerMeta(DisplayHandlerMeta):
    @addId
    def getMenuInfo(self,entity, dataHandler):
        # if we have DataFrame, include the menu option
        if entity.__class__.__name__ == "DataFrame":
            return [
                {
                    "categoryId": "Chart",
                    "title": "Simple Word Cloud",
                    "icon": "fa-cloud",
                    "id": "mySimpleWordCloud"
                }
            ]
        else:
            return []
    
    """
    Factory method that creates the displayHandler class capable of visualizing the data
    """
    def newDisplayHandler(self,options,entity):
        return WordCloudDisplayHandler(options,entity)


# -------------------------------------------------------------------------------
# Generated by PixieDust code generator
# 
# Licensed under the Apache License, Version 2.0 (the 'License');
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
# http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# Inherited from maven-artifact https://github.com/hamnis/maven-artifact
# -------------------------------------------------------------------------------

from pixiedust.display.display import Display
from pixiedust.utils import Logger

from wordcloud import WordCloud
import cStringIO
import base64

@Logger()
class WordCloudDisplayHandler(Display):
    """
        Main Render method
    """
    def doRender(self,handlerId):
        # convert from dataframe to dict
        dfdict = {}
        df = self.entity.toPandas()
        for x in range(len(df)):
            currentid = df.iloc[x,0] or 'NoStreet'
            currentvalue = df.iloc[x,1]
            dfdict.setdefault(currentid, 0)
            dfdict[currentid] = dfdict[currentid] + currentvalue

        # create word cloud from dict
        wc = WordCloud(background_color="white").fit_words(dfdict)

        # encode word cloud image to base64 string
        b = cStringIO.StringIO()
        wc.to_image().save(b, format="PNG")
        img_str = base64.b64encode(b.getvalue())

        self._addHTMLTemplate("wordcloud.html", base64image=img_str.decode("ascii"))



# -------------------------------------------------------------------------------
# Generated by PixieDust code generator
# 
# Licensed under the Apache License, Version 2.0 (the 'License');
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
# http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# Inherited from maven-artifact https://github.com/hamnis/maven-artifact
# -------------------------------------------------------------------------------

from setuptools import setup, find_packages
setup(name='pixiedust_wordcloud',
	  version='0.2.2',
	  description='Word Cloud Visualization Plugin for PixieDust',
	  url='https://github.com/ibm-cds-labs/pixiedust_incubator',
	  install_requires=['pixiedust', 'wordcloud'],
	  author='vabarbosa',
	  author_email='va@us.ibm.com',
	  license='Apache 2.0',
	  packages=find_packages(),
		include_package_data=True,
	  zip_safe=False
)